@@ -1,9 +1,8 @@
 package BibTeX::Parser;
-our $VERSION = '0.3.2';
 
-# ABSTRACT: A pure perl BibTeX parser
 use warnings;
 use strict;
+use Text::Balanced qw(extract_bracketed extract_delimited);
 
 use BibTeX::Parser::Entry;
 
@@ -11,14 +10,16 @@ use BibTeX::Parser::Entry;
 
 =head1 NAME
 
-BibTeX::Parser - A pure perl BibTeX parser
+BibTeX::Parser - A plain perl BibTeX parser
 
 =head1 VERSION
 
-version 0.3.2
+Version 0.1
 
 =cut
 
+our $VERSION = '0.2';
+
 my $re_namechar = qr/[a-zA-Z0-9\!\$\&\*\+\-\.\/\:\;\<\>\?\[\]\^\_\`\|]/o;
 my $re_name     = qr/$re_namechar+/o;
 
@@ -27,7 +28,6 @@ my $re_name     = qr/$re_namechar+/o;
 Parses BibTeX files.
 
     use BibTeX::Parser;
-	use IO::File;
 
     my $fh     = IO::File->new("filename");
 
@@ -40,13 +40,13 @@ Parses BibTeX files.
 		    my $type    = $entry->type;
 		    my $title   = $entry->field("title");
 
-		    my @authors = $entry->author;
+		    my @authors = $entry->authors;
 		    # or:
-		    my @editors = $entry->editor;
+		    my @editors = $entry->editors;
 		    
 		    foreach my $author (@authors) {
-			    print $author->first . " "
-			    	. $author->von . " "
+			    print $author->first . " " 
+			    	. $author->von . " " 
 				. $author->last . ", "
 				. $author->jr;
 		    }
@@ -112,28 +112,20 @@ sub _parse_next {
         if (/@($re_name)/cgo) {
 			my $type = uc $1;
             $current_entry->type( $type );
-            my $start_pos = pos($_) - length($type) - 1;
 
-            # read rest of entry (matches braces)
+			# read rest of entry (matches braces
             my $bracelevel = 0;
             $bracelevel += tr/\{/\{/;    #count braces
             $bracelevel -= tr/\}/\}/;
             while ( $bracelevel != 0 ) {
                 my $position = pos($_);
                 my $line     = $self->{fh}->getline;
-				last unless defined $line;
                 $bracelevel =
                   $bracelevel + ( $line =~ tr/\{/\{/ ) - ( $line =~ tr/\}/\}/ );
                 $_ .= $line;
                 pos($_) = $position;
             }
 
-            # Remember raw bibtex code
-            my $raw = substr($_, $start_pos);
-            $raw =~ s/^\s+//;
-            $raw =~ s/\s+$//;
-            $current_entry->raw_bibtex($raw);
-
             my $pos = pos $_;
             tr/\n/ /;
             pos($_) = $pos;
@@ -237,7 +229,7 @@ sub _parse_string {
         {    # quoted string with embeded escapes
             $value .= $1;
         } else {
-            my $part = _extract_bracketed( $_ );
+            my $part = ( extract_bracketed( $_, "{}" ) )[0];
             $value .= substr $part, 1, length($part) - 2;    # strip quotes
         }
 
@@ -249,23 +241,17 @@ sub _parse_string {
     return $value;
 }
 
-sub _extract_bracketed
-{
-	for($_[0]) # alias to $_
-	{
-		/\G\s+/cg;
-		my $start = pos($_);
-		my $depth = 0;
-		while(1)
-		{
-			/\G\\./cg && next;
-			/\G\{/cg && (++$depth, next);
-			/\G\}/cg && (--$depth > 0 ? next : last);
-			/\G([^\\\{\}]+)/cg && next; 
-			last; # end of string
-		}
-		return substr($_, $start, pos($_)-$start);
-	}
-}
+=head1 AUTHOR
 
-1;    # End of BibTeX::Parser
\ No newline at end of file
+Gerhard Gossen, C<< <gerhard.gossen at googlemail.com> >>
+
+
+=head1 LICENSE
+
+This program is free software; you can redistribute it and/or modify it
+under the same terms as Perl itself.
+
+
+=cut
+
+1;    # End of BibTeX::Parser
